import { default as default_2 } from 'react';
import { FC } from 'react';

declare type AccordionListProps = {
    /**
     * Children of type Accordion, either one or more.
     * */
    children: default_2.ReactElement<AccordionProps> | default_2.ReactElement<AccordionProps>[];
    /**
     * Whether to show numbers on the left of accordions and a vertical line between the number or not.
     * */
    isOrdered?: boolean;
    /**
     * Whether to show a toggle all button or not.
     * */
    hasToggleAll?: boolean;
    /**
     * Text on the toggle all button when it is closed.
     * */
    langToggleOpen?: string;
    /**
     * Text on the toggle all button when it is open.
     * */
    langToggleClose?: string;
    /**
     * What the screen reader will read before it reads the contents of header
     * */
    langAriaSteps?: string;
};

declare type AccordionProps = {
    /**
     * Header element (ie. `{(<h3>My Title</h3>)}`)
     * */
    header: default_2.ReactNode;
    /**
     * Whether or not the accordion is open
     * */
    isOpen?: boolean;
    /**
     * Whether the background turns white when opened.
     * */
    isBackgroundWhite?: boolean;
    /**
     * Handler of button click and 'Enter' key down.
     * Overwrites the default of toggling open/close.
     * */
    onClick?: () => void;
    /**
     * What the screen reader will read before it reads the contents of header
     * Used with AccordionList
     * */
    langAriaSteps?: string;
    /**
     * Child elements or string
     * */
    children?: default_2.ReactNode;
    /**
     * Override randomized id used for linking button to content.
     * You can use this to stop next from complaining about value
     * that is different on server and client
     * */
    contentId?: string;
};

/**
 * Accordion that allows for toggling isOpen state by passing an onClick event.
 *
 * The props `isOpen` and `onClick` can be passed to set custom properties for
 * either when the accordion is open, and what event is triggered when clicked
 * respectively. By default the accordion is closed, and by default the accordion
 * is toggled open/closed on click.
 */
export declare const BlAccordion: default_2.FC<AccordionProps>;

/**
 * Ordered Accordion List that allows for an ordered list of Accordions as prop.
 * Can either be one or more. Applies the same functionality as Accordions but also with ordering.
 */
export declare const BlAccordionList: default_2.FC<AccordionListProps>;

/**
 * A wrapper around the button element. All extra props is passed to the button element.
 */
export declare const BlButton: default_2.FC<ButtonProps>;

/**
 * Carousel of images that you can click through.
 */
export declare const BlCarousel: default_2.FC<CarouselProps>;

/**
 * A wrapper around the input type checkbox element. All extra props is passed to the input element.
 */
export declare const BlCheckbox: default_2.FC<CheckboxProps>;

export declare const BlFooter: default_2.FC<FooterProps>;

/**
 * Hero Component with big image with a tile containing text.
 * Can be used as only content in tile or only image.
 */
export declare const BlHero: default_2.FC<HeroProps>;

/**
 * InfoBox component that consists mainly of a header with medium sized information icon, text and source/link.
 */
export declare const BlInfoBox: default_2.FC<InfoBoxProps>;

/**
 * A wrapper around the input type input element. All extra props is passed to the input element.
 */
export declare const BlInput: default_2.FC<InputProps>;

/**
 * Bufdir logo
 */
export declare const BlLogo: default_2.FC<LogoProps>;

export declare const BlMenuButton: default_2.FC<MenuButtonProps>;

/**
 * Native html dialog with set title and close icon
 * */
export declare const BlModal: FC<ModalProps>;

/**
 * Dropdown like component for selecting multiple options.
 *
 * Functionally this component is only a wrapper
 * around Checkbox components, so to manage the state,
 * do so in the Checkbox components.
 */
export declare const BlMultiselect: default_2.FC<MultiselectProps>;

/**
 * A wrapper around the input type radio button element. All extra props is passed to the input element.
 */
export declare const BlRadioButton: default_2.FC<RadioButtonProps>;

/**
 * ResponsiveImage component with optional extra props for device specific image urls.
 * Provides the opportunity to set different image sizing for specific screens/displays.
 */
export declare const BlResponsiveImage: FC<ResponsiveImageProps>;

export declare const BlSearch: default_2.FC<SearchProps>;

/**
 * Select component with optional semantic label. All extra props will be passed to the select element.
 */
export declare const BlSelect: default_2.FC<SelectProps>;

/**
 * A button with a tag style. Typically to indicate active filter options.
 *
 * All extra props is passed to the button element.
 */
export declare const BlTag: default_2.FC<TagProps>;

/**
 * This is a Teaser component that might have an image, some content and links.
 * Typically used to display part of the content found on a linked page.
 */
export declare const BlTeaser: default_2.FC<TeaserProps>;

/**
 * A wrapper around the textarea type textarea element. All extra props is passed to the textarea element.
 */
export declare const BlTextArea: default_2.FC<TextAreaProps>;

/**
 * Validation component with state options.
 *
 * Mainly to be used as form validation.
 */
export declare const BlValidation: default_2.FC<ValidationProps>;

declare type ButtonProps = {
    /**
     * Type of the button.
     * */
    type?: 'button' | 'submit' | 'reset';
    /**
     * Child elements or string
     */
    children: default_2.ReactNode;
    /**
     * Style type of the button.
     * */
    styleType?: 'primary' | 'secondary' | 'tertiary';
    /**
     * Size of the button.
     * */
    size?: 'small' | 'medium';
    /**
     * Whether the buttons action is loading.
     * */
    isLoading?: boolean;
    /**
     * Button elements onClick event that returns the native event. Log value example: onClick={(e) => {console.log(e)}}
     * */
    onClick?: (e: default_2.MouseEvent<HTMLButtonElement>) => void;
    /**
     * Whether or not the checkbox is disabled.
     * */
    isDisabled?: boolean;
    /**
     * Name of icon in kebab-case. For example: 'chevron-right'. See all icons in the icon docs.
     * */
    iconName?: string;
    /**
     * All extra props is passed to the button element.
     * */
    [x: string]: any;
};

declare type CarouselProps = {
    /**
     * Children of type ResponsiveImage or Image from NextJs, either one or more.
     * */
    children: default_2.ReactNode;
    /**
     * Whether to show interactive thumbnails or not.
     * */
    showThumbnails?: boolean;
    /**
     * Text to show to screen readers for the left button.
     * */
    ariaLeftButton?: string;
    /**
     * Text to show to screen readers for the right button.
     * */
    ariaRightButton?: string;
    /**
     * Text on the close button inside the fullscreen modal-
     * */
    txtCloseFullscreen?: string;
    /**
     * Whether the carousel is displayed within a modal.
     * */
    isInsideModal?: boolean;
    /**
     * Start at specific image index.
     * */
    initialActiveImage?: number;
};

declare type CheckboxProps = {
    /**
     * Label for the checkbox.
     * */
    label: default_2.ReactNode;
    /**
     * Whether or not the checkbox is checked.
     * */
    isChecked?: boolean;
    /**
     * Checkbox elements onChange event that returns the native onchange event. Log value example: onChange={(e) => {console.log(e.target.value)}}
     * */
    onChange?: (e: default_2.ChangeEvent<HTMLInputElement>) => void;
    /**
     * Whether or not the checkbox is checked by default.
     * */
    isDefaultChecked?: boolean;
    /**
     * Whether or not the checkbox is disabled.
     * */
    isDisabled?: boolean;
    /**
     * Override randomized id used for linking label to input.
     * You can use this to stop next from complaining about value
     * that is different on server and client
     * */
    inputId?: string;
    /**
     * All extra props is passed to the input element.
     * */
    [x: string]: any;
};

/**
 * Use this component at the bottom of any web page.
 * The component uses the semantic html5 element \<footer\>.
 * It should not be contained within a grid element,
 * but should be allowed to strech all the way from side to side.
 */
declare type FooterProps = {
    /**
     * Child elements or string
     * */
    children?: default_2.ReactNode;
    /**
     * Title of the footer
     * */
    title?: string;
    /**
     * Whether to show the "to-top-button"
     * */
    hasToTop?: boolean;
    /**
     * Selector for the element to focus when the "to-top-button" is clicked
     * */
    toTopFocusSelector?: string;
    /**
     * "to-top-button" text
     * */
    langToTop?: string;
    /**
     * "to-top-button" screen reader text
     * */
    langToTopHint?: string;
    /**
     * React element sent in as props.
     * */
    rightContent?: default_2.ReactNode;
    /**
     * React element in as props.
     * */
    leftContent?: default_2.ReactNode;
};

declare type HeroProps = {
    /**
     * Image component that generates an `<img>` tag. For example BlResponsiveImage.
     */
    imageElement?: default_2.ReactNode;
    /**
     * Whether to have alternate colors/themes for tile.
     * */
    theme?: 'primary' | 'secondary' | 'tertiary';
    /**
     * Whether the content text is centered or not.
     * */
    isCenterText?: boolean;
    /**
     * Child elements i.e. Tile
     * */
    children?: default_2.ReactNode;
};

declare type InfoBoxProps = {
    /**
     * Header string or element (ie. `{(<h3> My headline </h3>)}`)
     */
    header?: default_2.ReactNode;
    /**
     * Child elements or string
     */
    children?: default_2.ReactNode;
    /**
     *  Different variants declaring severity of information.
     * */
    state?: 'info' | 'success' | 'warning' | 'error';
    /**
     *  Remove icon from title
     * */
    hasNoIcon?: boolean;
    /**
     *  specify aria-live value for screen readers, default is null
     *  i.e. attribute is not rendered
     * */
    ariaLive?: 'polite' | 'assertive' | 'off';
};

declare type InputProps = {
    /**
     * Label for the input.
     * */
    label: string;
    /**
     * Type for the input.
     * */
    type?: string;
    /**
     * Value for the input.
     * */
    value?: string;
    /**
     * Placeholder for the input.
     * */
    placeholder?: string;
    /**
     * select elements onChange event that returns the native onchange event. Log value example: onChange={(e) => {console.log(e.target.value)}}
     * */
    onChange?: (e: default_2.ChangeEvent<HTMLInputElement>) => void;
    /**
     * State of the input.
     * */
    state?: 'success' | 'warning' | 'error';
    /**
     * Validation message.
     * */
    message?: string;
    /**
     * Whether or not the input field is disabled.
     * */
    isDisabled?: boolean;
    /**
     * All extra props is passed to the input element.
     * */
    [x: string]: any;
};

declare type LogoProps = {
    /**
     * Width of the logo
     * */
    width?: number;
    /**
     * Color of the logo
     * */
    color?: string;
};

declare type MenuButtonProps = {
    /**
     * Whether or not the button is active
     * */
    isActive?: boolean;
    /**
     * Button text when inactive
     * */
    langInactive?: string;
    /**
     * Button title when inactive
     * */
    langInactiveHint?: string;
    /**
     * Button text when active
     * */
    langActive?: string;
    /**
     * Button title when active
     * */
    langActiveHint?: string;
    /**
     * function to fire on click
     * */
    onClick: () => void;
    /**
     * All extra props is passed to the button element.
     * */
    [x: string]: any;
};

declare type ModalProps = {
    /**
     *  Rendered inside tile below title
     * */
    children: default_2.ReactNode;
    /**
     *  Sets the title for modal content.
     * */
    title?: string;
    /**
     *  ID for the modal.
     * */
    id?: string;
    /**
     *  Language for aria-label on backdrop
     * */
    langAriaModalClose?: string;
    /**
     *  Handling of open state
     * */
    isOpen?: boolean;
    /**
     *  Callback to handle logic on closing of modal outside of component
     * */
    onClose?: () => void;
};

declare type MultiselectProps = {
    /**
     * Label above the the multiselect.
     * */
    label: string;
    /**
     * Text for the button opening the multiselect.
     * */
    buttonText: string;
    /**
     * Checkbox components to be displayed in the multiselect.
     * */
    children?: default_2.ReactElement<CheckboxProps> | default_2.ReactElement<CheckboxProps>[];
    /**
     * Override randomized id used for linking button to listbox.
     * You can use this to stop next from complaining about value
     * that is different on server and client
     * */
    listboxId?: string;
    /**
     * Override randomized id used for linking label to button.
     * You can use this to stop next from complaining about value
     * that is different on server and client
     * */
    buttonId?: string;
    /**
     * All extra props is passed to the button element.
     * */
    [x: string]: any;
};

declare type RadioButtonProps = {
    /**
     * Label for the radio button.
     * */
    label: default_2.ReactNode;
    /**
     * Whether or not the radio button is checked.
     * */
    isChecked?: boolean;
    /**
     * select elements onChange event that returns the native onchange event. Log value example: onChange={(e) => {console.log(e.target.value)}}
     * */
    onChange?: (e: default_2.ChangeEvent<HTMLInputElement>) => void;
    /**
     * Whether or not the radio button is checked by default.
     * */
    isDefaultChecked?: boolean;
    /**
     * Whether or not the radio button is disabled.
     * */
    isDisabled?: boolean;
    /**
     * Override randomized id used for linking label to input.
     * You can use this to stop next from complaining about value
     * that is different on server and client
     * */
    inputId?: string;
    /**
     * All extra props is passed to the input element.
     *
     * */
    [x: string]: any;
};

declare type ResponsiveImageProps = {
    /**
     * Default/fallback image url
     */
    url?: string;
    /**
     * Text describing the image for screen readers
     */
    ariaText?: string;
    /**
     * Optional image url spesifically for small screen
     */
    mobileUrl?: string;
    /**
     * Optional image url for medium sized screen and larger
     */
    tabletUrl?: string;
    /**
     * Optional image override url for large sized screen and larger
     */
    desktopUrl?: string;
    /**
     * Optional image override url for extra large sized screen and larger
     */
    widescreenUrl?: string;
    /**
     * Optional text displayed under the image
     */
    caption?: string;
    /**
     * Optional text to show attribution or any text on the image
     */
    credit?: string;
    /**
     * Optionally override the whole image element. Useful with Next.js Image component
     */
    imageElement?: default_2.ReactNode;
};

declare type SearchProps = {
    /**
     * Whether or not the input field is open/visible
     * */
    isOpen?: boolean;
    /**
     * Event that fires on input enter key, and on button click when isOpen={true} and text exists in the input field
     * */
    onClickSearch: (e: string) => void;
    /**
     * Event that fires on button click when isOpen={false} (typically to open the closed input field by setting isOpen={true})
     * */
    onClickShow: () => void;
    /**
     * Set's the placeholder of the input field. Also used for sr only label text
     * */
    placeholder?: string;
    /**
     * Set's the text of the button
     * */
    buttonText?: string;
    /**
     * Override randomized id used for linking label to input.
     * You can use this to stop next from complaining about value
     * that is different on server and client
     * */
    inputId?: string;
    /**
     * All extra props is passed to the input element.
     * */
    [x: string]: any;
};

declare type SelectProps = {
    /**
     * HTML option elements.
     * */
    children: default_2.ReactNode;
    /**
     * State of the select.
     * */
    state?: 'success' | 'warning' | 'error';
    /**
     * Validation message.
     * */
    message?: string;
    /**
     * Show that the select is disabled or read-only.
     * */
    isDisabled?: boolean;
    /**
     * Select elements name attribute
     * */
    name?: string;
    /**
     * Text for a label with a "for" attribute to semantically tie the label to the select element.
     * */
    label: default_2.ReactNode;
    /**
     * Control value by passing in state, and update state with onChange
     * */
    value?: string;
    /**
     * onChange event that returns the native onchange event. Log value example: onChange={(e) => {console.log(e.target.value)}}
     * */
    onChange?: (e: default_2.ChangeEvent<HTMLSelectElement>) => void;
    /**
     * Override randomized id used for linking label to select.
     * You can use this to stop next from complaining about value
     * that is different on server and client
     * */
    inputId?: string;
    /**
     * All extra props is passed to the select element.
     * */
    [x: string]: any;
};

declare type TagProps = {
    /**
     * Tell screen readers what happens on click. Goes to the buttons title attribute.
     */
    ariaText: string;
    /**
     * Child elements or string
     */
    children: default_2.ReactNode;
    /**
     * Size of the tag.
     * */
    size?: 'small' | 'medium';
    /**
     * Style type of the tag.
     * */
    styleType?: 'primary' | 'secondary';
    /**
     * Name of complementary icon. 'close' for primary, 'edit' and 'plus-circle' for secondary.
     * */
    iconName?: 'close' | 'pencil' | 'plus-circle';
    /**
     * Button elements onClick event that returns the native event. Log value example: onClick={(e) => {console.log(e)}}
     * */
    onClick?: (e: default_2.MouseEvent<HTMLButtonElement>) => void;
    /**
     * All extra props is passed to the input element.
     * */
    [x: string]: any;
};

declare type TeaserProps = {
    /**
     * Image component that generates an `<img>` tag. For example BlResponsiveImage.
     */
    imageElement?: default_2.ReactNode;
    /**
     *  Image position can be left or right on desktop
     * */
    imagePosition?: undefined | 'left' | 'right';
    /**
     * Headline text/title.
     */
    header?: default_2.ReactNode;
    /**
     * Children
     */
    children?: default_2.ReactNode;
};

declare type TextAreaProps = {
    /**
     * Label for the textarea.
     * */
    label: string;
    /**
     * Value for the textarea.
     * */
    value?: string;
    /**
     * Placeholder for the textarea.
     * */
    placeholder?: string;
    /**
     * select elements onChange event that returns the native onchange event. Log value example: onChange={(e) => {console.log(e.target.value)}}
     * */
    onChange?: (e: default_2.ChangeEvent<HTMLTextAreaElement>) => void;
    /**
     * State of the textarea.
     * */
    state?: 'success' | 'warning' | 'error';
    /**
     * Validation message.
     * */
    message?: string;
    /**
     * Whether or not the textarea is disabled.
     * */
    isDisabled?: boolean;
    /**
     * All extra props is passed to the textarea element.
     * */
    [x: string]: any;
};

declare type ValidationProps = {
    /**
     * Child elements or string
     */
    children: default_2.ReactNode;
    /**
     *  Different variants declaring severity of information.
     * */
    state?: 'info' | 'success' | 'warning' | 'error';
    /**
     *  Remove icon from title
     * */
    hasNoIcon?: boolean;
    /**
     * All extra props is passed to the root element.
     * */
    [x: string]: any;
};

export { }
