'use client';
import React, { useEffect, useMemo, useState } from 'react';
import { makeUniqueId } from '../../helpers/js/functions';

import './Accordion.scss';

export type AccordionProps = {
  /**
   * Header element (ie. `{(<h3>My Title</h3>)}`)
   * */
  header: React.ReactNode;
  /**
   * Whether or not the accordion is open
   * */
  isOpen?: boolean;
  /**
   * Whether the background turns white when opened.
   * */
  isBackgroundWhite?: boolean;
  /**
   * Handler of button click and 'Enter' key down.
   * Overwrites the default of toggling open/close.
   * */
  onClick?: () => void;
  /**
   * What the screen reader will read before it reads the contents of header
   * Used with AccordionList
   * */
  langAriaSteps?: string;
  /**
   * Child elements or string
   * */
  children?: React.ReactNode;
  /**
   * Override randomized id used for linking button to content.
   * You can use this to stop next from complaining about value
   * that is different on server and client
   * */
  contentId?: string;
};

/**
 * Accordion that allows for toggling isOpen state by passing an onClick event.
 *
 * The props `isOpen` and `onClick` can be passed to set custom properties for
 * either when the accordion is open, and what event is triggered when clicked
 * respectively. By default the accordion is closed, and by default the accordion
 * is toggled open/closed on click.
 */
const Accordion: React.FC<AccordionProps> = ({
  header,
  children = null,
  isOpen = false,
  onClick = undefined,
  isBackgroundWhite = false,
  langAriaSteps,
  contentId,
}) => {
  const [isOpenDefault, setIsOpenDefault] = useState(isOpen);
  const randomId = useMemo(() => makeUniqueId(), []);

  const toggleIsOpenDefault = () => {
    setIsOpenDefault(!isOpenDefault);
  };

  useEffect(() => {
    setIsOpenDefault(isOpen);
  }, [isOpen]);

  return (
    <div
      className={`bl-accordion${
        isBackgroundWhite ? ' bl-accordion--is-white' : ''
      }${
        isOpenDefault ? ' bl-accordion--is-open' : ' bl-accordion--is-closed'
      }`}
    >
      <div
        className="bl-accordion__header"
        onClick={onClick || toggleIsOpenDefault}
        onKeyDown={(event: React.KeyboardEvent<HTMLDivElement>) => {
          if (event.key === 'Enter') {
            if (onClick) {
              onClick();
            } else {
              toggleIsOpenDefault();
            }
          }
        }}
        role="button"
        tabIndex={0}
        aria-expanded={isOpenDefault}
        aria-controls={contentId || randomId}
      >
        {langAriaSteps && <span className="bl-sr-only">{langAriaSteps}:</span>}

        <div className="bl-accordion__header-content">{header}</div>
        <div className="bl-accordion__icon">
          <i className="bl-icon--chevron-down bl-icon--small" />
        </div>
      </div>
      <div id={contentId || randomId} className="bl-accordion__content">
        {children}
      </div>
    </div>
  );
};

export default Accordion;
