'use client';
import React, { useState } from 'react';
import { AccordionProps } from '../accordion/Accordion';

import './AccordionList.scss';

type AccordionListProps = {
  /**
   * Children of type Accordion, either one or more.
   * */
  children:
    | React.ReactElement<AccordionProps>
    | React.ReactElement<AccordionProps>[];
  /**
   * Whether to show numbers on the left of accordions and a vertical line between the number or not.
   * */
  isOrdered?: boolean;
  /**
   * Whether to show a toggle all button or not.
   * */
  hasToggleAll?: boolean;
  /**
   * Text on the toggle all button when it is closed.
   * */
  langToggleOpen?: string;
  /**
   * Text on the toggle all button when it is open.
   * */
  langToggleClose?: string;
  /**
   * What the screen reader will read before it reads the contents of header
   * */
  langAriaSteps?: string;
};

/**
 * Ordered Accordion List that allows for an ordered list of Accordions as prop.
 * Can either be one or more. Applies the same functionality as Accordions but also with ordering.
 */
const AccordionList: React.FC<AccordionListProps> = ({
  children,
  isOrdered = false,
  hasToggleAll = false,
  langToggleOpen = 'Åpne alle',
  langToggleClose = 'Lukk alle',
  langAriaSteps,
}) => {
  const [isOpen, setIsOpen] = useState<boolean>(false);
  const numberOfAccordionChildren = React.Children.toArray(children).length;
  return (
    <>
      {hasToggleAll && numberOfAccordionChildren > 1 && (
        <div className="bl-accordion-list__toggle bl-p-b-1">
          <button type="button" onClick={() => setIsOpen(!isOpen)}>
            {isOpen ? langToggleClose : langToggleOpen}
          </button>
        </div>
      )}
      <div
        className={`bl-accordion-list${
          isOrdered ? ' bl-accordion-list--is-ordered' : ''
        }`}
      >
        {children &&
          React.Children.map(
            children,
            (child: React.ReactElement<AccordionProps>, index) =>
              React.isValidElement(child) &&
              React.cloneElement(child, {
                isOpen: hasToggleAll ? isOpen : child.props?.isOpen,
                langAriaSteps:
                  isOrdered && langAriaSteps && `${langAriaSteps} ${index + 1}`,
              }),
          )}
      </div>
    </>
  );
};

export default AccordionList;
