'use client';
import React from 'react';
import Loader from '../loader/Loader';

type ButtonProps = {
  /**
   * Type of the button.
   * */
  type?: 'button' | 'submit' | 'reset';
  /**
   * Child elements or string
   */
  children: React.ReactNode;
  /**
   * Style type of the button.
   * */
  styleType?: 'primary' | 'secondary' | 'tertiary';
  /**
   * Size of the button.
   * */
  size?: 'small' | 'medium';
  /**
   * Whether the buttons action is loading.
   * */
  isLoading?: boolean;
  /**
   * Button elements onClick event that returns the native event. Log value example: onClick={(e) => {console.log(e)}}
   * */
  onClick?: (e: React.MouseEvent<HTMLButtonElement>) => void;
  /**
   * Whether or not the checkbox is disabled.
   * */
  isDisabled?: boolean;
  /**
   * Name of icon in kebab-case. For example: 'chevron-right'. See all icons in the icon docs.
   * */
  iconName?: string;
  /**
   * All extra props is passed to the button element.
   * */
  [x: string]: any;
};

/**
 * A wrapper around the button element. All extra props is passed to the button element.
 */
const Button: React.FC<ButtonProps> = ({
  type = 'button',
  children,
  styleType = 'primary',
  size = 'medium',
  isLoading = false,
  onClick,
  isDisabled = false,
  iconName,
  ...rest
}) => {
  return (
    <button
      {...rest}
      className={`bl-button${size ? ` bl-button--${size}` : ''}${
        isLoading ? ' bl-button--loading' : ''
      }${styleType ? ` bl-button--${styleType}` : ''}`}
      onClick={onClick}
      type={type}
      disabled={isDisabled}
    >
      {children}
      {iconName && <i aria-hidden className={`bl-icon--${iconName}`} />}
      {isLoading && (
        <Loader
          isDark={styleType === 'secondary' || styleType === 'tertiary'}
        />
      )}
    </button>
  );
};

export default Button;
