// Carousel.test.js
import React from 'react';
import { render, fireEvent } from '@testing-library/react';
import BlCarousel from './Carousel';
import BlResponsiveImage from '../responsive_image/ResponsiveImage';

const props = {
  txtCloseFullscreen: 'Close',
};

const imagesProps = [
  {
    key: '1',
    url: 'https://via.placeholder.com/500x400',
    ariaText: 'Lorem ipsum',
    caption: 'Image 1 Caption',
  },
  {
    key: '2',
    url: 'https://via.placeholder.com/500x350',
    ariaText: 'Lorem ipsum',
    caption: 'Image 2 Caption',
  },
  {
    key: '3',
    url: 'https://via.placeholder.com/500x340',
    ariaText: 'Lorem ipsum',
    caption: 'Image 3 Caption',
  },
];

const selectors = {
  root: '.bl-carousel',
  btnNext: '.bl-carousel__right-button',
  btnFullscreen: '.bl-carousel__slides',
  activeSlideCaption: '.bl-carousel__slide-active span',
  thumbnails: '.bl-carousel__thumbnails',
  modal: '.bl-carousel-modal',
};

const images = imagesProps.map((imageProps) => (
  <BlResponsiveImage {...imageProps} />
));

const Carousel = <BlCarousel {...props}>{images}</BlCarousel>;

test('Carousel renders with initial active image', () => {
  const { container } = render(
    <BlCarousel {...props} initialActiveImage={2}>
      {images}
    </BlCarousel>,
  );

  const activeImageCaption = container.querySelector(
    selectors.activeSlideCaption,
  );
  expect(activeImageCaption).toHaveTextContent(imagesProps[2].caption);
  expect(activeImageCaption).not.toHaveTextContent(imagesProps[0].caption);
});

test('next image is active when next button is clicked', () => {
  const { container } = render(Carousel);

  let activeImageCaption = container.querySelector(
    selectors.activeSlideCaption,
  );

  expect(activeImageCaption).toHaveTextContent(imagesProps[0].caption);

  const btnNext = container.querySelector(selectors.btnNext);
  fireEvent.click(btnNext);

  activeImageCaption = container.querySelector(selectors.activeSlideCaption);
  expect(activeImageCaption).toHaveTextContent(imagesProps[1].caption);
  expect(activeImageCaption).not.toHaveTextContent(imagesProps[0].caption);
});

test('thumbnails are shown when showThumbnails is true', () => {
  const { container } = render(
    <BlCarousel {...props} showThumbnails>
      {images}
    </BlCarousel>,
  );

  const thumbnailsWrapper = container.querySelector(selectors.thumbnails);
  expect(thumbnailsWrapper).toBeInTheDocument();
});

test('thumbnails are hidden when showThumbnails is false', () => {
  const { queryByTestId } = render(
    <BlCarousel {...props} showThumbnails={false}>
      {images}
    </BlCarousel>,
  );

  const thumbnailsWrapper = queryByTestId(selectors.thumbnails);
  expect(thumbnailsWrapper).toBeNull();
});

test('Carousel opens fullscreen modal when clicked', () => {
  const { container } = render(Carousel);

  fireEvent.click(container.querySelector(selectors.btnFullscreen));

  const activeImageCaption = container
    .querySelector(selectors.modal)
    .querySelector(selectors.activeSlideCaption);
  expect(activeImageCaption).toHaveTextContent(imagesProps[0].caption);
});

test('Carousel closes fullscreen modal when close button is clicked', () => {
  const { container, getByText, queryByText } = render(Carousel);

  fireEvent.click(container.querySelector(selectors.btnFullscreen));

  const activeImageCaption = container
    .querySelector(selectors.modal)
    .querySelector(selectors.activeSlideCaption);
  expect(activeImageCaption).toHaveTextContent(imagesProps[0].caption);

  const closeButton = getByText(props.txtCloseFullscreen);
  fireEvent.click(closeButton);

  const modalContent = queryByText(selectors.modal);
  expect(modalContent).toBeNull();
});
