'use client';
/* eslint-disable jsx-a11y/no-noninteractive-element-interactions */

import React, { useEffect, useRef, useState } from 'react';

import CarouselModal from './carousel_modal/CarouselModal';

import './Carousel.scss';

type CarouselProps = {
  /**
   * Children of type ResponsiveImage or Image from NextJs, either one or more.
   * */
  children: React.ReactNode;
  /**
   * Whether to show interactive thumbnails or not.
   * */
  showThumbnails?: boolean;
  /**
   * Text to show to screen readers for the left button.
   * */
  ariaLeftButton?: string;
  /**
   * Text to show to screen readers for the right button.
   * */
  ariaRightButton?: string;
  /**
   * Text on the close button inside the fullscreen modal-
   * */
  txtCloseFullscreen?: string;
  /**
   * Whether the carousel is displayed within a modal.
   * */
  isInsideModal?: boolean;
  /**
   * Start at specific image index.
   * */
  initialActiveImage?: number;
};

/**
 * Carousel of images that you can click through.
 */
const Carousel: React.FC<CarouselProps> = ({
  children = null,
  showThumbnails = true,
  ariaLeftButton = 'Gå til forrige bilde',
  ariaRightButton = 'Gå til neste bilde',
  txtCloseFullscreen = 'Lukk',
  isInsideModal = false,
  initialActiveImage = 0,
}) => {
  const [currentImageIndex, setCurrentImageIndex] =
    useState(initialActiveImage);
  const sliderRef = useRef<HTMLUListElement>(null);
  const thumbnailsRef = useRef<HTMLUListElement>(null);
  const [isFullscreen, setIsFullscreen] = useState<boolean>(false);
  const totalNumberOfImages = React.Children.toArray(children).length;

  const closeFullscreen = () => {
    setIsFullscreen(false);
    sliderRef.current?.focus();
  };

  const scrollToActiveImage = () => {
    const activeCarouselSlide = sliderRef.current?.children[
      currentImageIndex
    ] as HTMLElement;

    sliderRef.current.scrollLeft = activeCarouselSlide.offsetLeft;
  };

  const centerThumbnail = () => {
    const thumbnailsWrapper = thumbnailsRef.current as HTMLElement;
    const activeThumbnail = thumbnailsWrapper?.children[
      currentImageIndex
    ] as HTMLElement;

    thumbnailsWrapper.scrollLeft =
      activeThumbnail.offsetLeft -
      thumbnailsWrapper.offsetWidth / 2 +
      activeThumbnail.offsetWidth / 2;
  };

  useEffect(() => {
    scrollToActiveImage();
    if (showThumbnails) {
      centerThumbnail();
    }
  }, [currentImageIndex]);

  return (
    <div className="bl-carousel">
      <div className="bl-carousel__main-wrapper">
        <fieldset className="bl-carousel__buttons" aria-controls="carousel">
          <button
            type="button"
            onClick={() =>
              setCurrentImageIndex((prev) =>
                prev === 0 ? totalNumberOfImages - 1 : prev - 1,
              )
            }
            className="bl-carousel__left-button"
          >
            <span className="bl-sr-only">{ariaLeftButton}</span>
            <i className="bl-icon--chevron-left" />
          </button>
          <button
            type="button"
            onClick={() =>
              setCurrentImageIndex((prev) =>
                prev === totalNumberOfImages - 1 ? 0 : prev + 1,
              )
            }
            className="bl-carousel__right-button"
          >
            <span className="bl-sr-only">{ariaRightButton}</span>
            <i className="bl-icon--chevron-right" />
          </button>
        </fieldset>
        <ul
          className="bl-carousel__slides"
          ref={sliderRef}
          id="carousel"
          tabIndex={0}
          onClick={() => !isInsideModal && setIsFullscreen(true)}
          onKeyDown={(e) => {
            if (e.key === 'Enter' && !isInsideModal) {
              setIsFullscreen(true);
            }
            if (e.key === 'Tab' && isInsideModal) {
              document.getElementById('bl-carousel-modal-content')?.focus();
            }
          }}
        >
          {children &&
            React.Children.map(children, (child: React.ReactElement, i) => (
              <li
                className={`bl-carousel__slide${
                  i === currentImageIndex ? ' bl-carousel__slide-active' : ''
                }`}
                aria-hidden={i !== currentImageIndex}
              >
                {React.cloneElement(child, {
                  style: { ...child.props.style },
                  caption: `<span>${child.props.caption || ''}</span><span>${
                    i + 1
                  } / ${totalNumberOfImages}</span>`,
                })}
              </li>
            ))}
        </ul>
      </div>

      {showThumbnails && (
        <div className="bl-carousel__main-wrapper" aria-hidden>
          <ul className="bl-carousel__thumbnails" ref={thumbnailsRef}>
            {children &&
              React.Children.map(children, (child: React.ReactElement, i) => (
                <li
                  className={`bl-carousel__thumbnail-slide${
                    i === currentImageIndex
                      ? ' bl-carousel__thumbnail-slide-active'
                      : ''
                  }`}
                  onClick={() => setCurrentImageIndex(i)}
                  onKeyDown={(e) => {
                    if (e.key === 'Enter') {
                      setCurrentImageIndex(i);
                    }
                  }}
                >
                  {React.cloneElement(child, {
                    style: { ...child.props.style },
                  })}
                </li>
              ))}
          </ul>
        </div>
      )}
      <CarouselModal
        isOpen={isFullscreen}
        onBackdropClick={() => closeFullscreen()}
        langAriaModalClose={txtCloseFullscreen}
      >
        <div className="bl-carousel__close-modal-button-wrapper">
          <button
            className="bl-carousel__close-modal-button"
            onClick={() => closeFullscreen()}
          >
            {txtCloseFullscreen}
            <i className="bl-icon bl-icon--close bl-p-l-2" />
          </button>
        </div>
        <Carousel
          isInsideModal
          showThumbnails={false}
          initialActiveImage={currentImageIndex}
        >
          {children}
        </Carousel>
      </CarouselModal>
    </div>
  );
};

export default Carousel;
