'use client';
import React, { forwardRef, useMemo } from 'react';

import { makeUniqueId } from '../../helpers/js/functions';

export type CheckboxProps = {
  /**
   * Label for the checkbox.
   * */
  label: React.ReactNode;
  /**
   * Whether or not the checkbox is checked.
   * */
  isChecked?: boolean;
  /**
   * Checkbox elements onChange event that returns the native onchange event. Log value example: onChange={(e) => {console.log(e.target.value)}}
   * */
  onChange?: (e: React.ChangeEvent<HTMLInputElement>) => void;
  /**
   * Whether or not the checkbox is checked by default.
   * */
  isDefaultChecked?: boolean;
  /**
   * Whether or not the checkbox is disabled.
   * */
  isDisabled?: boolean;
  /**
   * Override randomized id used for linking label to input.
   * You can use this to stop next from complaining about value
   * that is different on server and client
   * */
  inputId?: string;
  /**
   * All extra props is passed to the input element.
   * */
  [x: string]: any;
};

/**
 * A wrapper around the input type checkbox element. All extra props is passed to the input element.
 */
const Checkbox: React.FC<CheckboxProps> = forwardRef<
  HTMLInputElement,
  CheckboxProps
>(
  (
    {
      label,
      isChecked,
      onChange,
      isDefaultChecked,
      isDisabled,
      inputId,
      ...rest
    },
    ref,
  ) => {
    const randomId = useMemo(() => makeUniqueId(), []);
    return (
      <div className="bl-checkbox">
        <input
          {...rest}
          ref={ref}
          onChange={onChange}
          type="checkbox"
          id={inputId || randomId}
          defaultChecked={isDefaultChecked}
          disabled={isDisabled}
          checked={isChecked}
        />
        <label htmlFor={inputId || randomId}>{label}</label>
      </div>
    );
  },
);

export default Checkbox;
