import React from 'react';

import './Footer.scss';
import Logo from '../logo/Logo';
import FooterIllustration from './FooterIllustration';
import { smoothScrollTo } from '../../helpers/js/functions';
import Button from '../button/Button';

/**
 * Use this component at the bottom of any web page.
 * The component uses the semantic html5 element \<footer\>.
 * It should not be contained within a grid element,
 * but should be allowed to strech all the way from side to side.
 */

type FooterProps = {
  /**
   * Child elements or string
   * */
  children?: React.ReactNode;
  /**
   * Title of the footer
   * */
  title?: string;
  /**
   * Whether to show the "to-top-button"
   * */
  hasToTop?: boolean;
  /**
   * Selector for the element to focus when the "to-top-button" is clicked
   * */
  toTopFocusSelector?: string;
  /**
   * "to-top-button" text
   * */
  langToTop?: string;
  /**
   * "to-top-button" screen reader text
   * */
  langToTopHint?: string;
  /**
   * React element sent in as props.
   * */
  rightContent?: React.ReactNode;
  /**
   * React element in as props.
   * */
  leftContent?: React.ReactNode;
};

const Footer: React.FC<FooterProps> = ({
  children = null,
  title = '',
  hasToTop = true,
  langToTop = 'Til toppen',
  toTopFocusSelector = null,
  langToTopHint = 'Gå til toppen av siden',
  rightContent = null,
  leftContent = null,
}) => {
  const smoothScrollToTop = () => {
    smoothScrollTo({
      top: 0,
      callback: () => {
        if (toTopFocusSelector) {
          const focusElement: HTMLElement =
            document.querySelector(toTopFocusSelector);
          focusElement.focus();
        }
      },
    });
  };
  return (
    <footer className="bl-footer bl-bg-sand-4">
      <div className="bl-footer__container bl-p-y-8 bl-p-x-3">
        <div className="bl-footer__logo bl-p-b-4">
          <Logo />
        </div>
        <div className="bl-footer__section">
          <div className="bl-footer__left">
            {title && (
              <div className="bl-footer__title bl-m-b-3">
                <h2 className="bl-size-3">{title}</h2>
              </div>
            )}
            {leftContent}
          </div>

          {children && (
            <div className="bl-footer__children bl-p-b-4">{children}</div>
          )}
          <div className="bl-footer__right">{rightContent}</div>
        </div>
      </div>
      {hasToTop && (
        <div className="bl-footer__to-top">
          <Button
            onClick={() => {
              smoothScrollToTop();
            }}
            iconName="chevron-up"
            styleType="secondary"
            title={langToTopHint}
          >
            {langToTop}
          </Button>
        </div>
      )}
      <div aria-hidden className="bl-footer__watermark">
        <FooterIllustration />
      </div>
    </footer>
  );
};

export default Footer;
