'use client';
import React, { useEffect, FC, useRef } from 'react';
import './Modal.scss';

type ModalProps = {
  /**
   *  Rendered inside tile below title
   * */
  children: React.ReactNode;
  /**
   *  Sets the title for modal content.
   * */
  title?: string;
  /**
   *  ID for the modal.
   * */
  id?: string;
  /**
   *  Language for aria-label on backdrop
   * */
  langAriaModalClose?: string;
  /**
   *  Handling of open state
   * */
  isOpen?: boolean;
  /**
   *  Callback to handle logic on closing of modal outside of component
   * */
  onClose?: () => void;
};

/**
 * Native html dialog with set title and close icon
 * */
const Modal: FC<ModalProps> = ({
  children,
  langAriaModalClose = 'Lukk Modal',
  title = '',
  isOpen = false,
  onClose = () => null,
  id = null,
}) => {
  const dialog = useRef(null);

  const open = () => {
    if (dialog.current?.open) return;

    document.body.style.overflow = 'hidden';
    dialog.current?.showModal();
  };
  const close = () => {
    if (!dialog.current?.open) return;
    document.body.style.overflow = 'scroll';
    onClose();
    dialog.current?.close();
  };

  useEffect(() => {
    if (isOpen && !dialog.current?.open) open();
    if (!isOpen && dialog.current?.open) close();
  }, [isOpen]);

  useEffect(() => {
    const escapeClickCloseEvent = (e) => {
      if (e.key === 'Escape') {
        close();
      }
    };
    // HTML dialog does not natively support closing by clicking outside the modal
    // This useEffect adds support for this.
    const outsideClickCloseEvent = (e: MouseEvent) => {
      const dialogDimensions = dialog.current?.getBoundingClientRect();
      const isMouseOutsideModal =
        e.clientX < dialogDimensions.left ||
        e.clientX > dialogDimensions.right ||
        e.clientY < dialogDimensions.top ||
        e.clientY > dialogDimensions.bottom;

      if (isMouseOutsideModal) {
        close();
      }
    };
    dialog.current?.addEventListener('mousedown', outsideClickCloseEvent);
    dialog.current?.addEventListener('keydown', escapeClickCloseEvent);
    return () => {
      dialog.current?.removeEventListener('mousedown', outsideClickCloseEvent);
      dialog.current?.addEventListener('keydown', escapeClickCloseEvent);
    };
  }, []);

  return (
    <dialog className="bl-modal" id={id} ref={dialog}>
      <div className="bl-modal__container bl-tile">
        <div className="bl-modal__header">
          {title && <h2 className="bl-size-2">{title}</h2>}

          <button
            aria-label={langAriaModalClose}
            onClick={() => close()}
            className="bl-modal__close"
          >
            <i className="bl-icon--close bl-icon--medium" />
          </button>
        </div>
        {children}
      </div>
    </dialog>
  );
};
export default Modal;
