'use client';
import React, { useMemo, useRef, useState } from 'react';
import { makeUniqueId } from '../../helpers/js/functions';
import { useOutsideRefClickCallback } from '../../helpers/js/hooks';
import { CheckboxProps } from '../checkbox/Checkbox';

import './Multiselect.scss';

type MultiselectProps = {
  /**
   * Label above the the multiselect.
   * */
  label: string;
  /**
   * Text for the button opening the multiselect.
   * */
  buttonText: string;
  /**
   * Checkbox components to be displayed in the multiselect.
   * */
  children?:
    | React.ReactElement<CheckboxProps>
    | React.ReactElement<CheckboxProps>[];
  /**
   * Override randomized id used for linking button to listbox.
   * You can use this to stop next from complaining about value
   * that is different on server and client
   * */
  listboxId?: string;
  /**
   * Override randomized id used for linking label to button.
   * You can use this to stop next from complaining about value
   * that is different on server and client
   * */
  buttonId?: string;
  /**
   * All extra props is passed to the button element.
   * */
  [x: string]: any;
};

/**
 * Dropdown like component for selecting multiple options.
 *
 * Functionally this component is only a wrapper
 * around Checkbox components, so to manage the state,
 * do so in the Checkbox components.
 */
const Multiselect: React.FC<MultiselectProps> = ({
  label,
  buttonText,
  children = null,
  buttonId,
  listboxId,
  ...rest
}) => {
  const [isOpen, setIsOpen] = useState(false);
  const multiselectRef = useRef<HTMLDivElement>(null);
  const randomListboxId = useMemo(() => makeUniqueId(), []);
  const randomButtonId = useMemo(() => makeUniqueId(), []);

  // Close the multiselect when the user clicks outside of it.
  useOutsideRefClickCallback(multiselectRef, () => setIsOpen(false));

  return (
    <div className="bl-multiselect__wrapper">
      <label
        className="bl-size-6 bl-display-block"
        htmlFor={buttonId || randomButtonId}
      >
        {label}
      </label>
      <div
        className={`bl-multiselect${
          isOpen ? ' bl-multiselect--is-open' : ''
        } bl-m-t-1`}
        ref={multiselectRef}
      >
        <button
          {...rest}
          id={buttonId || randomButtonId}
          type="button"
          onClick={() => setIsOpen(!isOpen)}
          className="bl-multiselect__button bl-input"
          aria-expanded={isOpen}
          aria-controls={listboxId || randomListboxId}
          aria-haspopup="listbox"
        >
          <span>{buttonText}</span>
          <i className="bl-multiselect__icon bl-icon--chevron-down bl-icon--small" />
        </button>

        {children && (
          <div className="bl-multiselect__children-wrapper">
            <div
              id={listboxId || randomListboxId}
              role="listbox"
              aria-multiselectable="true"
              className="bl-multiselect__children"
            >
              {children}
            </div>
          </div>
        )}
      </div>
    </div>
  );
};

export default Multiselect;
