'use client';
import React, { forwardRef, useMemo } from 'react';

import { makeUniqueId } from '../../helpers/js/functions';

type RadioButtonProps = {
  /**
   * Label for the radio button.
   * */
  label: React.ReactNode;
  /**
   * Whether or not the radio button is checked.
   * */
  isChecked?: boolean;
  /**
   * select elements onChange event that returns the native onchange event. Log value example: onChange={(e) => {console.log(e.target.value)}}
   * */
  onChange?: (e: React.ChangeEvent<HTMLInputElement>) => void;
  /**
   * Whether or not the radio button is checked by default.
   * */
  isDefaultChecked?: boolean;
  /**
   * Whether or not the radio button is disabled.
   * */
  isDisabled?: boolean;
  /**
   * Override randomized id used for linking label to input.
   * You can use this to stop next from complaining about value
   * that is different on server and client
   * */
  inputId?: string;
  /**
   * All extra props is passed to the input element.
   *
   * */
  [x: string]: any;
};

/**
 * A wrapper around the input type radio button element. All extra props is passed to the input element.
 */
const RadioButton: React.FC<RadioButtonProps> = forwardRef<
  HTMLInputElement,
  RadioButtonProps
>(
  (
    {
      label,
      isChecked,
      onChange,
      isDefaultChecked,
      isDisabled,
      inputId,
      ...rest
    },
    ref,
  ) => {
    const randomId = useMemo(() => makeUniqueId(), []);
    return (
      <div className="bl-radio-button">
        <input
          {...rest}
          ref={ref}
          type="radio"
          id={inputId || randomId}
          onChange={onChange}
          defaultChecked={isDefaultChecked}
          disabled={isDisabled}
          checked={isChecked}
        />
        <label htmlFor={inputId || randomId}>{label}</label>
      </div>
    );
  },
);

export default RadioButton;
