import React, { FC } from 'react';

import './ResponsiveImage.scss';

type ResponsiveImageProps = {
  /**
   * Default/fallback image url
   */
  url?: string;
  /**
   * Text describing the image for screen readers
   */
  ariaText?: string;
  /**
   * Optional image url spesifically for small screen
   */
  mobileUrl?: string;
  /**
   * Optional image url for medium sized screen and larger
   */
  tabletUrl?: string;
  /**
   * Optional image override url for large sized screen and larger
   */
  desktopUrl?: string;
  /**
   * Optional image override url for extra large sized screen and larger
   */
  widescreenUrl?: string;
  /**
   * Optional text displayed under the image
   */
  caption?: string;
  /**
   * Optional text to show attribution or any text on the image
   */
  credit?: string;
  /**
   * Optionally override the whole image element. Useful with Next.js Image component
   */
  imageElement?: React.ReactNode;
};

/**
 * ResponsiveImage component with optional extra props for device specific image urls.
 * Provides the opportunity to set different image sizing for specific screens/displays.
 */
const ResponsiveImage: FC<ResponsiveImageProps> = ({
  url,
  ariaText,
  mobileUrl,
  tabletUrl,
  desktopUrl,
  widescreenUrl,
  caption,
  credit,
  imageElement,
}) => (
  <figure className="bl-responsive-image">
    <div className="bl-responsive-image__spacer" />
    <picture>
      {mobileUrl && <source srcSet={mobileUrl} media="(max-width: 766px)" />}
      {tabletUrl && <source srcSet={tabletUrl} media="(min-width: 768px)" />}
      {desktopUrl && <source srcSet={desktopUrl} media="(min-width: 1200px)" />}
      {widescreenUrl && (
        <source srcSet={widescreenUrl} media="(min-width: 1950px)" />
      )}
      {imageElement ? (
        imageElement
      ) : (
        <img className="bl-responsive-image__image" src={url} alt={ariaText} />
      )}
    </picture>
    {caption && (
      <figcaption
        className="bl-responsive-image__caption bl-p-t-1"
        dangerouslySetInnerHTML={{ __html: caption }}
      />
    )}
    {credit && (
      <div className="bl-responsive-image__credit bl-size-6 bl-p-a-1">
        {credit}
      </div>
    )}
    <div className="bl-responsive-image__spacer" />
  </figure>
);

export default ResponsiveImage;
