'use client';
import React, { useMemo, useRef } from 'react';

import './Search.scss';
import { makeUniqueId } from '../../helpers/js/functions';

type SearchProps = {
  /**
   * Whether or not the input field is open/visible
   * */
  isOpen?: boolean;
  /**
   * Event that fires on input enter key, and on button click when isOpen={true} and text exists in the input field
   * */
  onClickSearch: (e: string) => void;
  /**
   * Event that fires on button click when isOpen={false} (typically to open the closed input field by setting isOpen={true})
   * */
  onClickShow: () => void;
  /**
   * Set's the placeholder of the input field. Also used for sr only label text
   * */
  placeholder?: string;
  /**
   * Set's the text of the button
   * */
  buttonText?: string;
  /**
   * Override randomized id used for linking label to input.
   * You can use this to stop next from complaining about value
   * that is different on server and client
   * */
  inputId?: string;
  /**
   * All extra props is passed to the input element.
   * */
  [x: string]: any;
};

const Search: React.FC<SearchProps> = ({
  isOpen = false,
  onClickShow,
  onClickSearch,
  placeholder = 'Søk',
  buttonText = 'Søk',
  inputId,
  ...rest
}) => {
  const textInput = useRef(null);
  const randomId = useMemo(() => makeUniqueId(), []);
  return (
    <div
      className={`bl-search ${
        isOpen ? 'bl-search--open' : 'bl-search--closed'
      }`}
    >
      <label htmlFor={inputId || randomId} className="bl-sr-only">
        {placeholder}
      </label>
      <input
        {...rest}
        tabIndex={isOpen ? 0 : -1}
        id={inputId || randomId}
        className="bl-search__input bl-input bl-size-3"
        onKeyDown={(e: React.KeyboardEvent<HTMLInputElement>) =>
          e.key === 'Enter' && onClickSearch(textInput?.current?.value)
        }
        ref={textInput}
        type="text"
        placeholder={placeholder}
      />

      <button
        className="bl-search__button bl-size-3"
        onClick={() => {
          if (isOpen && textInput?.current?.value) {
            onClickSearch(textInput?.current?.value);
          } else {
            textInput?.current?.focus();
            onClickShow();
          }
        }}
        type="button"
      >
        <span className="bl-search__text">{buttonText}</span>
        <i className="bl-search__icon bl-icon--search bl-icon--medium" />
      </button>
    </div>
  );
};

export default Search;
