'use client';
import React, { forwardRef, useMemo } from 'react';

import { makeUniqueId } from '../../helpers/js/functions';
import './Select.scss';
import Validation from '../validation/Validation';

type SelectProps = {
  /**
   * HTML option elements.
   * */
  children: React.ReactNode;
  /**
   * State of the select.
   * */
  state?: 'success' | 'warning' | 'error';
  /**
   * Validation message.
   * */
  message?: string;
  /**
   * Show that the select is disabled or read-only.
   * */
  isDisabled?: boolean;
  /**
   * Select elements name attribute
   * */
  name?: string;
  /**
   * Text for a label with a "for" attribute to semantically tie the label to the select element.
   * */
  label: React.ReactNode;
  /**
   * Control value by passing in state, and update state with onChange
   * */
  value?: string;
  /**
   * onChange event that returns the native onchange event. Log value example: onChange={(e) => {console.log(e.target.value)}}
   * */
  onChange?: (e: React.ChangeEvent<HTMLSelectElement>) => void;
  /**
   * Override randomized id used for linking label to select.
   * You can use this to stop next from complaining about value
   * that is different on server and client
   * */
  inputId?: string;
  /**
   * All extra props is passed to the select element.
   * */
  [x: string]: any;
};

/**
 * Select component with optional semantic label. All extra props will be passed to the select element.
 */
const Select: React.FC<SelectProps> = forwardRef<
  HTMLSelectElement,
  SelectProps
>(
  (
    {
      children,
      state,
      message,
      isDisabled = false,
      label = null,
      name = null,
      onChange = null,
      inputId,
      ...rest
    },
    ref,
  ) => {
    const randomId = useMemo(() => makeUniqueId(), []);
    return (
      <div className="bl-select">
        <label
          className="bl-select__label bl-size-6 bl-display-block bl-p-b-1"
          htmlFor={inputId || randomId}
        >
          {label}
        </label>
        <div className="bl-select__icon-wrapper">
          <i className="bl-select__icon bl-icon--chevron-down bl-icon--small" />
          <select
            {...rest}
            ref={ref}
            id={inputId || randomId}
            name={name}
            disabled={isDisabled}
            className={`bl-input${state ? ` bl-input--${state}` : ''}`}
            onChange={onChange}
          >
            {children}
          </select>
        </div>
        {message && (
          <div className="bl-p-t-1">
            <Validation state={state}>{message}</Validation>
          </div>
        )}
      </div>
    );
  },
);

export default Select;
