'use client';
import React, { forwardRef } from 'react';

import './Tag.scss';

type TagProps = {
  /**
   * Tell screen readers what happens on click. Goes to the buttons title attribute.
   */
  ariaText: string;
  /**
   * Child elements or string
   */
  children: React.ReactNode;
  /**
   * Size of the tag.
   * */
  size?: 'small' | 'medium';
  /**
   * Style type of the tag.
   * */
  styleType?: 'primary' | 'secondary';
  /**
   * Name of complementary icon. 'close' for primary, 'edit' and 'plus-circle' for secondary.
   * */
  iconName?: 'close' | 'pencil' | 'plus-circle';
  /**
   * Button elements onClick event that returns the native event. Log value example: onClick={(e) => {console.log(e)}}
   * */
  onClick?: (e: React.MouseEvent<HTMLButtonElement>) => void;
  /**
   * All extra props is passed to the input element.
   * */
  [x: string]: any;
};

/**
 * A button with a tag style. Typically to indicate active filter options.
 *
 * All extra props is passed to the button element.
 */
const Tag: React.FC<TagProps> = forwardRef<HTMLButtonElement, TagProps>(
  (
    {
      children,
      size = 'medium',
      styleType = 'primary',
      iconName,
      onClick,
      ariaText,
      ...rest
    },
    ref,
  ) => {
    return (
      <button
        {...rest}
        type="button"
        title={ariaText}
        onClick={onClick}
        ref={ref}
        className={`bl-tag${size ? ` bl-tag--${size}` : ''}${
          styleType ? ` bl-tag--${styleType}` : ''
        } bl-size-${size === 'small' ? '6' : '5'}`}
      >
        {children}
        {iconName && (
          <>
            {' '}
            <i
              className={`bl-icon--${iconName} bl-icon--x-small${
                styleType === 'primary' ? '-white' : ''
              } bl-m-l-1`}
            />
          </>
        )}
      </button>
    );
  },
);

export default Tag;
